"""
    FreeClimb API

    FreeClimb is a cloud-based application programming interface (API) that puts the power of the Vail platform in your hands. FreeClimb simplifies the process of creating applications that can use a full range of telephony features without requiring specialized or on-site telephony equipment. Using the FreeClimb REST API to write applications is easy! You have the option to use the language of your choice or hit the API directly. Your application can execute a command by issuing a RESTful request to the FreeClimb API. The base URL to send HTTP requests to the FreeClimb REST API is: /apiserver. FreeClimb authenticates and processes your request.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: support@freeclimb.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from datetime import datetime, date
import pytest

import freeclimb
from freeclimb.model.message_request_all_of import MessageRequestAllOf
from freeclimb.model.mutable_resource_model import MutableResourceModel
globals()['MessageRequestAllOf'] = MessageRequestAllOf
globals()['MutableResourceModel'] = MutableResourceModel

from freeclimb.model.message_request import MessageRequest  # noqa: E501

class TestMessageRequest(unittest.TestCase):
    """MessageRequest unit test stubs"""

    def setUp(self):
        self.model = MessageRequest(
            _from="",
            to="",
            text="",
        )
    
    def test_uri(self):
        """Test MessageRequest.uri"""
        self.model.uri = "TEST_STRING"
        assert self.model.get("uri") == "TEST_STRING"

    def test_date_created(self):
        """Test MessageRequest.date_created"""
        self.model.date_created = "TEST_STRING"
        assert self.model.get("date_created") == "TEST_STRING"

    def test_date_updated(self):
        """Test MessageRequest.date_updated"""
        self.model.date_updated = "TEST_STRING"
        assert self.model.get("date_updated") == "TEST_STRING"

    def test_revision(self):
        """Test MessageRequest.revision"""
        self.model.revision = 1
        assert self.model.get("revision") == 1

    def test__from(self):
        """Test MessageRequest._from"""
        self.model._from = "TEST_STRING"
        assert self.model.get("_from") == "TEST_STRING"

    def test_to(self):
        """Test MessageRequest.to"""
        self.model.to = "TEST_STRING"
        assert self.model.get("to") == "TEST_STRING"

    def test_text(self):
        """Test MessageRequest.text"""
        self.model.text = "TEST_STRING"
        assert self.model.get("text") == "TEST_STRING"

    def test_notification_url(self):
        """Test MessageRequest.notification_url"""
        self.model.notification_url = "TEST_STRING"
        assert self.model.get("notification_url") == "TEST_STRING"

    def test_account_id(self):
        """Test MessageRequest.account_id"""
        self.model.account_id = "TEST_STRING"
        assert self.model.get("account_id") == "TEST_STRING"

if __name__ == '__main__':
    unittest.main()
